pub fn parse_module(source: &str, module_name: &str) -> FrontendResult<Module>Expand description
Parse Rust source into a factorio_ir::module::Module.
module_name is used as the module identifier in the resulting IR.
Errors
Returns Err if the Rust source fails to parse